@@ -2,7 +2,7 @@
 
 namespace Doctrine\DBAL\Tests\Functional;
 
-use Doctrine\DBAL\Connection;
+use Doctrine\DBAL\ArrayParameterType;
 use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
@@ -26,7 +26,7 @@ class NamedParametersTest extends FunctionalTestCase
                 ],
                 [
                     'foo' => ParameterType::INTEGER,
-                    'bar' => Connection::PARAM_INT_ARRAY,
+                    'bar' => ArrayParameterType::INTEGER,
                 ],
                 [
                     ['id' => 1, 'foo' => 1, 'bar' => 1],
@@ -42,7 +42,7 @@ class NamedParametersTest extends FunctionalTestCase
                     'bar' => [1, 2, 3],
                 ],
                 [
-                    'bar' => Connection::PARAM_INT_ARRAY,
+                    'bar' => ArrayParameterType::INTEGER,
                     'foo' => ParameterType::INTEGER,
                 ],
                 [
@@ -59,7 +59,7 @@ class NamedParametersTest extends FunctionalTestCase
                     'bar' => [1, 2, 3],
                 ],
                 [
-                    'bar' => Connection::PARAM_INT_ARRAY,
+                    'bar' => ArrayParameterType::INTEGER,
                     'foo' => ParameterType::INTEGER,
                 ],
                 [
@@ -76,7 +76,7 @@ class NamedParametersTest extends FunctionalTestCase
                     'bar' => ['1', '2', '3'],
                 ],
                 [
-                    'bar' => Connection::PARAM_STR_ARRAY,
+                    'bar' => ArrayParameterType::STRING,
                     'foo' => ParameterType::INTEGER,
                 ],
                 [
@@ -93,8 +93,8 @@ class NamedParametersTest extends FunctionalTestCase
                     'bar' => [1, 2, 3, 4],
                 ],
                 [
-                    'bar' => Connection::PARAM_STR_ARRAY,
-                    'foo' => Connection::PARAM_INT_ARRAY,
+                    'bar' => ArrayParameterType::STRING,
+                    'foo' => ArrayParameterType::INTEGER,
                 ],
                 [
                     ['id' => 1, 'foo' => 1, 'bar' => 1],
@@ -136,7 +136,7 @@ class NamedParametersTest extends FunctionalTestCase
                     'arg' => [1, 2],
                 ],
                 [
-                    'arg' => Connection::PARAM_INT_ARRAY,
+                    'arg' => ArrayParameterType::INTEGER,
                 ],
                 [
                     ['id' => 3, 'foo' => 1, 'bar' => 3],
